#!/bin/csh -f

# shell program to test WekaClassify

# set up test file 
set TESTFILE     = "test-1.xml.arff"

# target files 
set TARGETFILE_1 = "test-1.sub-1.reqd"   
set TARGETFILE_2 = "test-1.sub-2.reqd" 
set TARGETFILE_3 = "test-1.sub-3.reqd" 
set TARGETFILE_4 = "test-1.sub-4.reqd" 

# model file
set MODELFILE    = "test-1.model"

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_1)) then
    echo "File $TARGETFILE_1 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_2)) then
    echo "File $TARGETFILE_2 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_3)) then
    echo "File $TARGETFILE_3 does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE_4)) then
    echo "File $TARGETFILE_4 does not exist... aborting"
    exit
endif

if (!(-e $MODELFILE)) then
    echo "File $MODELFILE does not exist... aborting"
    exit
endif

# first sub test : without -p switch
echo "Sub test 1: without -p switch"

echo "Testing WekaClassify thusly: java WekaClassify -l $MODELFILE -T $TESTFILE"
java WekaClassify -l $MODELFILE -T $TESTFILE > out

# find diffs
diff out $TARGETFILE_1 > difference

if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_1) ... ok"
else
    echo "Following differences exist between the output and $TARGETFILE_1 :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f out

# second sub test : with -p switch
echo "Sub test 2: with -p switch"

# second test
echo "Testing WekaClassify thusly: java WekaClassify -l $MODELFILE -t $TESTFILE -p 10"
java WekaClassify -l $MODELFILE -T $TESTFILE -p 10 > out

# find diffs
diff out $TARGETFILE_2 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_2) ... ok"
else
    echo "Following differences exist between out and $TARGETFILE_2 :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f out

# third sub test : check for missing -T
echo "Sub test 3: check for missing -T"

# third test
echo "Testing WekaClassify thusly: java WekaClassify -l $MODELFILE"
java WekaClassify -l $MODELFILE > out

# find diffs
diff out $TARGETFILE_3 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_3) ... ok"
else
    echo "Following differences exist between out and $TARGETFILE_3 :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f out

# fourth sub test : check for missing -l
echo "Sub test 4: check for missing -l"

echo "Testing WekaClassify thusly: java WekaClassify -T $TESTFILE"
java WekaClassify -T $TESTFILE > out

# find diffs
diff out $TARGETFILE_4 > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE_4) ... ok"
else
    echo "Following differences exist between out and $TARGETFILE_4 :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f out

